Struct tikv_client::request::plan::ExtractError
source · pub struct ExtractError<P: Plan> {
pub inner: P,
}Expand description
When executed, the plan extracts errors from its inner plan, and returns an
Err wrapping the error.
We usually need to apply this plan if (and only if) the output of the inner plan is of a response type.
The errors come from two places: Err from inner plans, and Ok(response)
where response contains unresolved errors (error and region_error).
Fields
inner: PTrait Implementations
sourceimpl<P: Plan> Clone for ExtractError<P>
impl<P: Plan> Clone for ExtractError<P>