Struct tikv_client::Key
source · pub struct Key(_);Expand description
The key part of a key/value pair.
In TiKV, keys are an ordered sequence of bytes. This has an advantage over choosing String as
valid UTF-8 is not required. This means that the user is permitted to store any data they wish,
as long as it can be represented by bytes. (Which is to say, pretty much anything!)
This type wraps around an owned value, so it should be treated it like String or Vec<u8>.
Examples
use tikv_client::Key;
let static_str: &'static str = "TiKV";
let from_static_str = Key::from(static_str.to_owned());
let string: String = String::from(static_str);
let from_string = Key::from(string);
assert_eq!(from_static_str, from_string);
let vec: Vec<u8> = static_str.as_bytes().to_vec();
let from_vec = Key::from(vec);
assert_eq!(from_static_str, from_vec);
let bytes = static_str.as_bytes().to_vec();
let from_bytes = Key::from(bytes);
assert_eq!(from_static_str, from_bytes);While .into() is usually sufficient for obtaining the buffer itself, sometimes type inference
isn’t able to determine the correct type. Notably in the assert_eq!() and == cases. In
these cases using the fully-qualified-syntax is useful:
Examples
use tikv_client::Key;
let buf = "TiKV".as_bytes().to_owned();
let key = Key::from(buf.clone());
assert_eq!(Into::<Vec<u8>>::into(key), buf);Many functions which accept a Key accept an Into<Key>, which means all of the above types
can be passed directly to those functions.
Implementations